@@ -70,6 +70,29 @@
 //! - If not present, we'll not verify the output
 //! - If `binary = false` in `*.toml` (the default), newlines will be normalized before comparing
 //!
+//! ##### Eliding Content
+//!
+//! Sometimes the output either includes:
+//! - Content that changes from run-to-run (like time)
+//! - Content out of scope of your tests and you want to exclude it to reduce brittleness
+//!
+//! To elide a section of content:
+//! - `...` as its own line will match all lines until the next one.  This is equivalent of
+//!   `(([^\n]*\n)*?`.
+//!
+//! We will preserve these with `TRYCMD=dump` and will make a best-effort at preserving them with
+//! `TRYCMD=overwrite`.
+//!
+//! #### `*.in/`
+//!
+//! When present, this will automatically be picked as the CWD for the command
+//!
+//! #### `*.out/`
+//!
+//! When present, each file in this directory will be compared to generated or modified files.
+//!
+//! See also "Eliding Content" for `.stdout`
+//!
 //! ### Workflow
 //!
 //! To generate snapshots, run
@@ -96,6 +119,8 @@ mod cargo;
 mod cases;
 mod color;
 mod command;
+pub(crate) mod elide;
+mod filesystem;
 mod runner;
 pub mod schema;
 mod spec;
@@ -105,6 +130,7 @@ pub use cases::TestCases;
 pub(crate) use cargo::cargo_bin;
 pub(crate) use color::Palette;
 pub(crate) use command::wait_with_input_output;
+pub(crate) use filesystem::{shallow_copy, FilesystemContext, Iterate as FsIterate};
 pub(crate) use runner::{Case, Mode, Runner};
 pub(crate) use schema::{Bin, CommandStatus, Env, TryCmd};
 pub(crate) use spec::RunnerSpec;
